import { StepInfoNode } from "../model/tactic/Tactic"

export function addStepNode(
    root: StepInfoNode,
    parent: StepInfoNode,
    child: StepInfoNode,
): StepInfoNode {
    if (root.id === parent.id) {
        return {
            ...root,
            children: root.children.concat(child),
        }
    }

    return {
        ...root,
        children: root.children.map((c) => addStepNode(c, parent, child)),
    }
}

export function getStepNode(
    root: StepInfoNode,
    stepId: number,
): StepInfoNode | undefined {
    if (root.id === stepId) return root

    for (const child of root.children) {
        const result = getStepNode(child, stepId)
        if (result) return result
    }
}

export function removeStepNode(
    root: StepInfoNode,
    node: StepInfoNode,
): StepInfoNode | undefined {
    if (root.id === node.id) {
        return undefined
    }

    return {
        ...root,
        children: root.children.flatMap((child) => {
            const result = removeStepNode(child, node)
            return result ? [result] : []
        }),
    }
}

/**
 * Returns an available identifier that is not already present into the given node tree
 * @param root
 */
export function getAvailableId(root: StepInfoNode): number {
    const acc = (root: StepInfoNode): number =>
        Math.max(root.id, ...root.children.map(acc))
    return acc(root) + 1
}

export function getParent(
    root: StepInfoNode,
    node: StepInfoNode,
): StepInfoNode | null {
    if (root.children.find((n) => n.id === node.id)) return root

    for (const child of root.children) {
        const result = getParent(child, node)
        if (result != null) {
            return result
        }
    }
    return null
}
